==> wmf_1.0.orig.tar.gz: wmf-1.0.orig/src/wmf.h <==
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <time.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <ctype.h>
#include <dirent.h>
#include <string.h>
#include <fcntl.h>
#include <setjmp.h>
#include "mime.h"
#include "html.h"

#ifdef FACES
#include <compface.h>
#endif

#ifdef DMALLOC
#include <dmalloc.h>
#endif

#define SORT_FORWARD		0
#define SORT_REVERSE		1

#define HTML_VERSION		"1.1"
#define HTML_NOMODE		-1
#define HTML_INDEX		0
#define HTML_OVERWRITE		1
#define HTML_APPEND		2
#define HTML_APPENDNOINDEX	3

#define WMF_NOVALUE		-1
#define WMF_NOSUBJECT		"(None)"

#define WMF_FRAME_TITLE		"title"
#define WMF_FRAME_INDEX		"index"
#define WMF_FRAME_MAIL		"mail"

#ifndef WMF_DEBUGLEVEL
#define WMF_DEBUGLEVEL		0
#endif

#ifndef FALSE
#define FALSE			0
#endif
#ifndef TRUE
#define TRUE			1
#endif
#ifndef BUFSIZ
#define BUFSIZ			10240
#endif

/* global constantes */

#ifdef INDEX_FILE
static char *reply_prefix[] = {"Re:","RE:","Re^2:","Re^4:","Aw:","AW:","re:",NULL};
#endif

#ifdef MAIL_FILE
static char *protocols[] = {"http:","gopher:","ftp:","news:","mailto:","file:",
	"wais:","telnet:",NULL};

#ifdef FACES
unsigned char FaceConvertTable[256] = {
        0x00, 0x80, 0x40, 0xc0, 0x20, 0xa0, 0x60, 0xe0,
        0x10, 0x90, 0x50, 0xd0, 0x30, 0xb0, 0x70, 0xf0,
        0x08, 0x88, 0x48, 0xc8, 0x28, 0xa8, 0x68, 0xe8,
        0x18, 0x98, 0x58, 0xd8, 0x38, 0xb8, 0x78, 0xf8,
        0x04, 0x84, 0x44, 0xc4, 0x24, 0xa4, 0x64, 0xe4,
        0x14, 0x94, 0x54, 0xd4, 0x34, 0xb4, 0x74, 0xf4,
        0x0c, 0x8c, 0x4c, 0xcc, 0x2c, 0xac, 0x6c, 0xec,
        0x1c, 0x9c, 0x5c, 0xdc, 0x3c, 0xbc, 0x7c, 0xfc,
        0x02, 0x82, 0x42, 0xc2, 0x22, 0xa2, 0x62, 0xe2,
        0x12, 0x92, 0x52, 0xd2, 0x32, 0xb2, 0x72, 0xf2,
        0x0a, 0x8a, 0x4a, 0xca, 0x2a, 0xaa, 0x6a, 0xea,
        0x1a, 0x9a, 0x5a, 0xda, 0x3a, 0xba, 0x7a, 0xfa,
        0x06, 0x86, 0x46, 0xc6, 0x26, 0xa6, 0x66, 0xe6,
        0x16, 0x96, 0x56, 0xd6, 0x36, 0xb6, 0x76, 0xf6,
        0x0e, 0x8e, 0x4e, 0xce, 0x2e, 0xae, 0x6e, 0xee,
        0x1e, 0x9e, 0x5e, 0xde, 0x3e, 0xbe, 0x7e, 0xfe,
        0x01, 0x81, 0x41, 0xc1, 0x21, 0xa1, 0x61, 0xe1,
        0x11, 0x91, 0x51, 0xd1, 0x31, 0xb1, 0x71, 0xf1,
        0x09, 0x89, 0x49, 0xc9, 0x29, 0xa9, 0x69, 0xe9,
        0x19, 0x99, 0x59, 0xd9, 0x39, 0xb9, 0x79, 0xf9,
        0x05, 0x85, 0x45, 0xc5, 0x25, 0xa5, 0x65, 0xe5,
        0x15, 0x95, 0x55, 0xd5, 0x35, 0xb5, 0x75, 0xf5,
        0x0d, 0x8d, 0x4d, 0xcd, 0x2d, 0xad, 0x6d, 0xed,
        0x1d, 0x9d, 0x5d, 0xdd, 0x3d, 0xbd, 0x7d, 0xfd,
        0x03, 0x83, 0x43, 0xc3, 0x23, 0xa3, 0x63, 0xe3,
        0x13, 0x93, 0x53, 0xd3, 0x33, 0xb3, 0x73, 0xf3,
        0x0b, 0x8b, 0x4b, 0xcb, 0x2b, 0xab, 0x6b, 0xeb,
        0x1b, 0x9b, 0x5b, 0xdb, 0x3b, 0xbb, 0x7b, 0xfb,
        0x07, 0x87, 0x47, 0xc7, 0x27, 0xa7, 0x67, 0xe7,
        0x17, 0x97, 0x57, 0xd7, 0x37, 0xb7, 0x77, 0xf7,
        0x0f, 0x8f, 0x4f, 0xcf, 0x2f, 0xaf, 0x6f, 0xef,
        0x1f, 0x9f, 0x5f, 0xdf, 0x3f, 0xbf, 0x7f, 0xff,
};
#endif
#endif

/* global variables */
#ifndef MAIN_FILE
extern
#endif
struct {
    char *ProgramName;
    int DebugLevel;
    int WriteMode;
    char *ConfigFile;
    char *MailBoxFile;
    char *MailCommand;
    char *Directory;
    char *Name;
    char *AboutLink;
    char *NoFaceFile;
    char *ReplyChars;
    char *FaceDirectory;
    char *DocStartFile;
    char *DocEndFile;
    int SortOrder;
    int PageSize;
    time_t ListLimit;
    time_t ListStart;
    time_t ListEnd;
    mode_t NewFilePerm;
    int ThreadLevelLimit;
    int ThreadNewSubject;
    int BodyHtmlConvert;
    int BodyLinkUrl;
    int BodyLinkEmail;
    int FaceSupport;
    int AuthorEmailSort;
    int AuthorCaseSort;
    int SubjectCaseSort;
    int ThreadCaseSort;
    int IndexAuthor;
    int IndexDate;
    int IndexSubject;
    int IndexThread;
    int LineSize;
    int CountMessages;
    int FrameSupport;
    char *FrameNameTitle;
    char *FrameNameIndex;
    char *FrameNameMail;
    int Statistics;
} config;

#ifndef MAIN_FILE
extern
#endif
struct {
    char *DocStart;
    char *DocEnd;
    char *HeadStart;
    char *HeadEnd;
    char *TitleStart;
    char *TitleEnd;
    char *BodyStart;
    char *BodyEnd;
    char *RemarkStart;
    char *RemarkEnd;
    char *PreStart;
    char *PreEnd;
    char *Title1Start;
    char *Title1End;
    char *Title2Start;
    char *Title2End;
    char *Title3Start;
    char *Title3End;
    char *Title4Start;
    char *Title4End;
    char *Title5Start;
    char *Title5End;
    char *Title6Start;
    char *Title6End;
    char *BoldStart;
    char *BoldEnd;
    char *ItalicStart;
    char *ItalicEnd;
    char *HrStart;
    char *HrEnd;
    char *ReplyStart;
    char *ReplyEnd;
} HtmlCmd;

#ifdef DEBUG
#ifndef MAIN_FILE
extern
#endif
struct DebugStruct {
    int StrAlloc;
    int StrDeAlloc;
    int MhAlloc;
    int MhDeAlloc;
    int MbAlloc;
    int MbDeAlloc;
} Debug;
#endif

struct MAILHEAD {
    struct MAILHEAD *Next;
    struct MAILHEAD *Prev;
    char *SendName;
    char *SendAddress;
    char *ReceiveName;
    char *ReceiveAddress;
    char *SentDate;
    char *MsgId;
    char *Reference;
    char *Subject;
    char *Xface;
    char *HomePage;
    char *FileName;
    char *AttachFile;
    int Printed;
    int InReply;
    int isort;
    char *ssort;
    int MimeType;
    int MimeCharset;
    int MimeEncode;
    char *MimeBoundary;
    char *MimeDescription;
};

struct MAILBODY {
    char *Line;
    struct MAILBODY *Next;
};



#ifndef CONFIG_FILE
/* config.c */
void *InitConfig(void);
void *DestroyConfig(void);
void *ReadConfig(void);
#endif

#ifndef DATE_FILE
/* index.c */
time_t *getutc(char *atime);
#endif

#ifndef INDEX_FILE
/* index.c */
void CreateIndex(void);
#endif

#ifndef FILE_FILE
/* file.c */
int FileExist(char *FileName);
char *CheckHomeDir(char *Name);
void AppendFile(char *FileName, char *Text);
void IncludeFile(char *FileName, char *FileInclude);
void NewFile(char *FileName, char *Text);
char *GetFileName(int number);
int GetNextFileNumber(int start);
void *CleanDirectory(char *DirName);
void *DelIndexFiles(void);
#endif

#ifndef MAIL_FILE
/* mail.c */
char *Email2Html(struct MAILHEAD *mh);
void Mail2Html(char *FileName);
#endif

#ifndef HTML_FILE
/* html.c */
void InitHtmlCmd();
void EndHtmlCmd();
void InitHtml(char *FileName);
void EndHtml(char *FileName);
char *ReadHtmlVarname(char *Line);
char *ReadHtmlValue(char *Line);
void WriteHtmlValue(char *FileName, char *Name, char *Value);
#endif

#ifndef SYS_FILE
/* sys.c */
#ifdef DMALLOC
#define newchar(x)	malloc(x)
#define	dupchar(x)	strdup(x)
#define	freechar(x)	free(x)
#else
char *newchar(int size);
char *dupchar(char *string);
void freechar(char *string);
int isoctal(char number);
#endif
#endif


#ifndef MIME_FILE
/* mime.c */
char *Quoted_2_Text(char *Zeile);
char *Text_2_Html(char *Zeile);
char *ByteConvert4to3(char *line, int *length, int MimeEncode);
int GetContentType(char *Zeile);
int GetContentEncode(char *Zeile);
char *GetBoundary(char *Zeile);
char *GetAttachmentName(char *Zeile);
int IfUuencode(char *line);
char *GetUuencodeFile(char *line);
int IsUrlChar(char Zeichen);
int GetCharset(char *Zeile);
int HeaderIsMimeEncoded(char *Zeile);
char *DecodeMimeHeader(char *line);
#endif

==> wmf_1.0.5.orig.tar.gz: wmf-1.0.5.orig/src/wmf.h <==
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <time.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <ctype.h>
#include <dirent.h>
#include <string.h>
#include <fcntl.h>
#include <setjmp.h>
#include "mime.h"
#include "html.h"

#ifdef FACES
#include <compface.h>
#endif

#ifdef DMALLOC
#include <dmalloc.h>
#endif

#define SORT_FORWARD		0
#define SORT_REVERSE		1

#define HTML_VERSION		"1.1"
#define HTML_NOMODE		-1
#define HTML_INDEX		0
#define HTML_OVERWRITE		1
#define HTML_APPEND		2
#define HTML_APPENDNOINDEX	3

#define WMF_NOVALUE		-1
#define WMF_NOSUBJECT		"(None)"

#define WMF_FRAME_TITLE		"title"
#define WMF_FRAME_INDEX		"index"
#define WMF_FRAME_MAIL		"mail"

#ifndef WMF_DEBUGLEVEL
#define WMF_DEBUGLEVEL		0
#endif

#ifndef WMF_EXTENSION
#define WMF_EXTENSION		".html"
#endif

#ifndef FALSE
#define FALSE			0
#endif
#ifndef TRUE
#define TRUE			1
#endif
#ifndef BUFSIZ
#define BUFSIZ			10240
#endif

/* global constantes */

#ifdef INDEX_FILE
static char *reply_prefix[] = {"Re:","RE:","Re^2:","Re^4:","Aw:","AW:","re:",NULL};
#endif

#ifdef MAIL_FILE
static char *protocols[] = {"http:","gopher:","ftp:","news:","file:",
	"wais:","telnet:",NULL};

#ifdef FACES
unsigned char FaceConvertTable[256] = {
        0x00, 0x80, 0x40, 0xc0, 0x20, 0xa0, 0x60, 0xe0,
        0x10, 0x90, 0x50, 0xd0, 0x30, 0xb0, 0x70, 0xf0,
        0x08, 0x88, 0x48, 0xc8, 0x28, 0xa8, 0x68, 0xe8,
        0x18, 0x98, 0x58, 0xd8, 0x38, 0xb8, 0x78, 0xf8,
        0x04, 0x84, 0x44, 0xc4, 0x24, 0xa4, 0x64, 0xe4,
        0x14, 0x94, 0x54, 0xd4, 0x34, 0xb4, 0x74, 0xf4,
        0x0c, 0x8c, 0x4c, 0xcc, 0x2c, 0xac, 0x6c, 0xec,
        0x1c, 0x9c, 0x5c, 0xdc, 0x3c, 0xbc, 0x7c, 0xfc,
        0x02, 0x82, 0x42, 0xc2, 0x22, 0xa2, 0x62, 0xe2,
        0x12, 0x92, 0x52, 0xd2, 0x32, 0xb2, 0x72, 0xf2,
        0x0a, 0x8a, 0x4a, 0xca, 0x2a, 0xaa, 0x6a, 0xea,
        0x1a, 0x9a, 0x5a, 0xda, 0x3a, 0xba, 0x7a, 0xfa,
        0x06, 0x86, 0x46, 0xc6, 0x26, 0xa6, 0x66, 0xe6,
        0x16, 0x96, 0x56, 0xd6, 0x36, 0xb6, 0x76, 0xf6,
        0x0e, 0x8e, 0x4e, 0xce, 0x2e, 0xae, 0x6e, 0xee,
        0x1e, 0x9e, 0x5e, 0xde, 0x3e, 0xbe, 0x7e, 0xfe,
        0x01, 0x81, 0x41, 0xc1, 0x21, 0xa1, 0x61, 0xe1,
        0x11, 0x91, 0x51, 0xd1, 0x31, 0xb1, 0x71, 0xf1,
        0x09, 0x89, 0x49, 0xc9, 0x29, 0xa9, 0x69, 0xe9,
        0x19, 0x99, 0x59, 0xd9, 0x39, 0xb9, 0x79, 0xf9,
        0x05, 0x85, 0x45, 0xc5, 0x25, 0xa5, 0x65, 0xe5,
        0x15, 0x95, 0x55, 0xd5, 0x35, 0xb5, 0x75, 0xf5,
        0x0d, 0x8d, 0x4d, 0xcd, 0x2d, 0xad, 0x6d, 0xed,
        0x1d, 0x9d, 0x5d, 0xdd, 0x3d, 0xbd, 0x7d, 0xfd,
        0x03, 0x83, 0x43, 0xc3, 0x23, 0xa3, 0x63, 0xe3,
        0x13, 0x93, 0x53, 0xd3, 0x33, 0xb3, 0x73, 0xf3,
        0x0b, 0x8b, 0x4b, 0xcb, 0x2b, 0xab, 0x6b, 0xeb,
        0x1b, 0x9b, 0x5b, 0xdb, 0x3b, 0xbb, 0x7b, 0xfb,
        0x07, 0x87, 0x47, 0xc7, 0x27, 0xa7, 0x67, 0xe7,
        0x17, 0x97, 0x57, 0xd7, 0x37, 0xb7, 0x77, 0xf7,
        0x0f, 0x8f, 0x4f, 0xcf, 0x2f, 0xaf, 0x6f, 0xef,
        0x1f, 0x9f, 0x5f, 0xdf, 0x3f, 0xbf, 0x7f, 0xff,
};
#endif
#endif

/* global variables */
#ifndef MAIN_FILE
extern
#endif
struct {
    char *ProgramName;
    int DebugLevel;
    int WriteMode;
    char *ConfigFile;
    char *MailBoxFile;
    char *MailCommand;
    char *Directory;
    char *Name;
    char *AboutLink;
    char *NoFaceFile;
    char *ReplyChars;
    char *FaceDirectory;
    char *DocStartFile;
    char *DocEndFile;
    int SortOrder;
    int PageSize;
    time_t ListLimit;
    time_t ListStart;
    time_t ListEnd;
    mode_t NewFilePerm;
    int ThreadLevelLimit;
    int ThreadNewSubject;
    int BodyHtmlConvert;
    int BodyLinkUrl;
    int BodyLinkEmail;
    int FaceSupport;
    int AuthorEmailSort;
    int AuthorCaseSort;
    int SubjectCaseSort;
    int ThreadCaseSort;
    int IndexAuthor;
    int IndexDate;
    int IndexSubject;
    int IndexThread;
    int LineSize;
    int CountMessages;
    int FrameSupport;
    char *FrameNameTitle;
    char *FrameNameIndex;
    char *FrameNameMail;
    int Statistics;
    char *Extension;
} config;

#ifndef MAIN_FILE
extern
#endif
struct {
    char *DocStart;
    char *DocEnd;
    char *HeadStart;
    char *HeadEnd;
    char *TitleStart;
    char *TitleEnd;
    char *BodyStart;
    char *BodyEnd;
    char *RemarkStart;
    char *RemarkEnd;
    char *PreStart;
    char *PreEnd;
    char *Title1Start;
    char *Title1End;
    char *Title2Start;
    char *Title2End;
    char *Title3Start;
    char *Title3End;
    char *Title4Start;
    char *Title4End;
    char *Title5Start;
    char *Title5End;
    char *Title6Start;
    char *Title6End;
    char *BoldStart;
    char *BoldEnd;
    char *ItalicStart;
    char *ItalicEnd;
    char *HrStart;
    char *HrEnd;
    char *ReplyStart;
    char *ReplyEnd;
} HtmlCmd;

#ifdef DEBUG
#ifndef MAIN_FILE
extern
#endif
struct DebugStruct {
    int StrAlloc;
    int StrDeAlloc;
    int MhAlloc;
    int MhDeAlloc;
    int MbAlloc;
    int MbDeAlloc;
} Debug;
#endif

struct MAILHEAD {
    struct MAILHEAD *Next;
    struct MAILHEAD *Prev;
    char *SendName;
    char *SendAddress;
    char *ReceiveName;
    char *ReceiveAddress;
    char *SentDate;
    char *MsgId;
    char *Reference;
    char *Subject;
    char *Xface;
    char *HomePage;
    char *FileName;
    char *AttachFile;
    int Printed;
    int InReply;
    time_t isort;
    char *ssort;
    int MimeType;
    int MimeCharset;
    int MimeEncode;
    char *MimeBoundary;
    char *MimeDescription;
};

struct MAILBODY {
    char *Line;
    struct MAILBODY *Next;
};



#ifndef CONFIG_FILE
/* config.c */
void *InitConfig(void);
void *DestroyConfig(void);
void *ReadConfig(void);
#endif

#ifndef DATE_FILE
/* index.c */
time_t getutc(char *atime);
#endif

#ifndef INDEX_FILE
/* index.c */
void CreateIndex(void);
#endif

#ifndef FILE_FILE
/* file.c */
int FileExist(char *FileName);
char *CheckHomeDir(char *Name);
void AppendFile(char *FileName, char *Text);
void IncludeFile(char *FileName, char *FileInclude);
void NewFile(char *FileName, char *Text);
char *GetFileName(int number);
int GetNextFileNumber(int start);
void *CleanDirectory(char *DirName);
void *DelIndexFiles(void);
#endif

#ifndef MAIL_FILE
/* mail.c */
char *Email2Html(struct MAILHEAD *mh);
void WriteIndexNavigation (char *Filename);
void Mail2Html(char *FileName);
#endif

#ifndef HTML_FILE
/* html.c */
void InitHtmlCmd();
void EndHtmlCmd();
void InitHtml(char *FileName);
void EndHtml(char *FileName);
char *ReadHtmlVarname(char *Line);
char *ReadHtmlValue(char *Line);
void WriteHtmlValue(char *FileName, char *Name, char *Value);
#endif

#ifndef SYS_FILE
/* sys.c */
#ifdef DMALLOC
#define newchar(x)	malloc(x)
#define	dupchar(x)	strdup(x)
#define	freechar(x)	free(x)
#else
char *newchar(int size);
char *dupchar(char *string);
void freechar(char *string);
int isoctal(char number);
#endif
#endif


#ifndef MIME_FILE
/* mime.c */
char *Quoted_2_Text(char *Zeile);
char *Text_2_Html(char *Zeile);
char *ByteConvert4to3(char *line, int *length, int MimeEncode);
int GetContentType(char *Zeile);
int GetContentEncode(char *Zeile);
char *GetBoundary(char *Zeile);
char *GetAttachmentName(char *Zeile);
int IfUuencode(char *line);
char *GetUuencodeFile(char *line);
int IsUrlChar(char Zeichen);
int GetCharset(char *Zeile);
int HeaderIsMimeEncoded(char *Zeile);
char *DecodeMimeHeader(char *line);
#endif
